@@ -3,14 +3,16 @@ A simple text editor written in Python.It supports editing text files,
 binary files ,encodings and changing font size.
 When you edit a binary file, the contents of the file are
 displayed as escape sequences.
-And code highlighting is supported when editing Python code files,like IDLE.
+You can also find and replace words.
+In addition, code highlighting is supported when editing Python code files,like IDLE.
 
 一款使用tkinter编写的文本编辑器, 支持编辑文本文件、二进制文件、改变字体大小。
-支持ansi、gbk和utf-8编码。编辑二进制文件时, 文件内容以转义序列形式显示。
+支持ansi、gbk、utf-8等编码。编辑二进制文件时, 文件内容以转义序列形式显示。
+支持查找、替换、改变字体大小; 且支持撤销、重做;
 编辑python代码文件时, 支持代码高亮显示, 类似IDLE。
 
 作者:qfcy (七分诚意)
-版本:1.2.5
+版本:1.2.6
 """
 import sys,os,time
 from tkinter import *
@@ -28,7 +30,7 @@ except ImportError:
 
 __email__="3416445406@qq.com"
 __author__="七分诚意 qq:3076711200 邮箱:%s"%__email__
-__version__="1.2.5"
+__version__="1.2.6"
 
 #_REPLACE_CHARS=['\x00','\r']
 def view_hex(bytes):
@@ -216,7 +218,7 @@ class Editor(Tk):
             #self.filenamebox.insert(END,filename)
             self.load(filename)
     def load_icon(self):
-        for path in sys.path:
+        for path in sys.path + [os.path.split(sys.executable)[0]]: # 用于Py2exe
             try:
                 self.iconbitmap("{}\{}".format(path,self.ICON))
             except TclError:pass
@@ -386,34 +388,33 @@ class Editor(Tk):
 
     def text_change(self,event=None):
         self.file_changed=True
-        self.update_offset()
+        self.update_status()
     def update_status(self,event=None):
         if self.isbinary:
             try:
                 selected=self.contents.get(SEL_FIRST,SEL_LAST)
                 data=to_bytes(selected)
-                try:
-                    text=str(data,encoding=self.coding.get(),
-                             errors="backslashreplace")
-                except TypeError:
-                    text=''
+                text=str(data,encoding=self.coding.get(),
+                         errors="backslashreplace")
                 self.bin_data.delete("1.0",END)
                 self.bin_data.insert(INSERT,text)
                 self.charmap.delete("1.0",END)
                 self.charmap.insert(INSERT,view_hex(data))
                 self.status["text"]="选区长度: %d (Bytes)"%len(data)
-            except (TclError,SyntaxError): #未选取内容
-                self.update_offset()
-        else:self.update_offset()
+            except (TclError,TypeError,SyntaxError): #未选取内容, 或格式不正确
+                self.bin_data.delete("1.0",END)
+                self.charmap.delete("1.0",END)
+        self.update_offset()
     def update_offset(self,event=None):
         if self.isbinary:
-            selected=self.contents.get("1.0",INSERT)
+            prev=self.contents.get("1.0",INSERT)
             try:
-                data=to_bytes(selected)
+                data=to_bytes(prev) # to_bytes_long(prev,master=self)
             except SyntaxError:
                 sep='\\'
-                selected=sep.join(selected.split(sep)[0:-1])
-                data=to_bytes(selected)
+                # self.update()
+                prev=sep.join(prev.split(sep)[0:-1])
+                data=to_bytes(prev)
             self.status["text"]="偏移量: {} ({})".format(len(data),hex(len(data)))
         else:
             offset=self.contents.index(CURRENT).split('.')
@@ -439,12 +440,9 @@ class Editor(Tk):
             return
         self.isbinary=binary
         if os.path.isfile(filename):
-            self.filename=filename
             data=self._load_data(filename)
-            if len(data)>10000:
-                self.title(
-                "%s - 加载中,请耐心等待..." % self.TITLE)
-                self.update()
+            if data==0:return
+            self.filename=filename
             self.contents.delete('1.0', END)
             if self.isbinary:
                 self.contents.insert(INSERT,data)
@@ -471,14 +469,16 @@ class Editor(Tk):
                 data=str(f.read(),encoding=self.coding.get())
             except UnicodeDecodeError:
                 f.seek(0)
-                result=msgbox.askyesno("","""%s编码无法解码此文件,
+                result=msgbox.askyesnocancel("PyNotepad","""%s编码无法解码此文件,
 是否使用二进制模式打开?"""%self.coding.get())
                 if result:
                     self.isbinary=True
                     data=to_escape_str(f.read())
-                else:
+                elif result is not None:
                     self.isbinary=False
                     data=str(f.read(),encoding=self.coding.get(),errors="replace")
+                else:
+                    return 0 # 表示取消
         return data
     def change_title(self,running=False):
         newtitle="PyNotepad - "+os.path.split(self.filename)[1]+\
